"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var parsing_1 = require("../parsing/parsing");
var deep_extends_1 = require("../deep-extends/deep-extends");
var fs = tslib_1.__importStar(require("fs-extra"));
var path = tslib_1.__importStar(require("path"));
var getPathAndFormat = function (input) {
    if (typeof input === 'string') {
        return { path: input };
    }
    else if (!input.raw) {
        return { path: input.path, format: input.format };
    }
    else {
        return { path: null, format: null };
    }
};
var getFileData = function (input, path) {
    if (path) {
        try {
            return fs.readFile(path, 'utf-8');
        }
        catch (e) {
            console.log("error in read: for " + path + ": " + e.message);
            return null;
        }
    }
    if (input.raw) {
        return input.raw;
    }
    return null;
};
function cobble(params) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var inputs, disableReadFile, ignoreMissingVariables, debug, objects, _i, inputs_1, input, _a, filePath, format, fileData, docs, i, doc, parsed, e_1, dirName, resolved, e_2;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    inputs = params.inputs, disableReadFile = params.disableReadFile, ignoreMissingVariables = params.ignoreMissingVariables;
                    debug = params.debug || (function (v) { });
                    if (!Array.isArray(inputs)) {
                        throw new Error("Please provide a list of inputs either as strings or { path: string, format: 'json' | 'yaml' | 'properties' } objects");
                    }
                    objects = [];
                    _i = 0, inputs_1 = inputs;
                    _b.label = 1;
                case 1:
                    if (!(_i < inputs_1.length)) return [3, 13];
                    input = inputs_1[_i];
                    _a = getPathAndFormat(input), filePath = _a.path, format = _a.format;
                    return [4, getFileData(input, filePath)];
                case 2:
                    fileData = _b.sent();
                    if (!fileData) {
                        return [3, 12];
                    }
                    docs = parsing_1.splitYamlIntoDocs(fileData);
                    i = 0;
                    _b.label = 3;
                case 3:
                    if (!(i < docs.length)) return [3, 12];
                    doc = docs[i];
                    parsed = void 0;
                    _b.label = 4;
                case 4:
                    _b.trys.push([4, 6, , 7]);
                    return [4, parsing_1.tryParse(doc, format)];
                case 5:
                    parsed = _b.sent();
                    debug("parsed: " + JSON.stringify(parsed));
                    return [3, 7];
                case 6:
                    e_1 = _b.sent();
                    debug("Could not parse: " + filePath + " for doc " + i + ": " + e_1.message + ", continuing");
                    return [3, 7];
                case 7:
                    if (disableReadFile) {
                        debug("file inlining is not enabled");
                        objects = objects.concat(parsed);
                        return [3, 11];
                    }
                    _b.label = 8;
                case 8:
                    _b.trys.push([8, 10, , 11]);
                    dirName = filePath ? path.dirname(filePath) : __dirname;
                    debug("dirName at " + dirName);
                    return [4, parsing_1.resolveFiles(parsed, dirName)];
                case 9:
                    resolved = _b.sent();
                    debug("resolved files: " + JSON.stringify(resolved));
                    objects = objects.concat(resolved);
                    return [3, 11];
                case 10:
                    e_2 = _b.sent();
                    debug("Could not resolve: " + filePath + " for doc " + i + ": " + e_2.message + ", continuing");
                    return [3, 11];
                case 11:
                    i++;
                    return [3, 3];
                case 12:
                    _i++;
                    return [3, 1];
                case 13:
                    if (!objects.length) {
                        throw new Error('No objects to work with');
                    }
                    objects = objects.filter(Boolean);
                    debug("got objects: " + JSON.stringify(objects));
                    if (params.varsObj) {
                        objects = objects.map(function (object) { return parsing_1.replaceTokens(object, params.varsObj, ignoreMissingVariables); });
                    }
                    return [2, deep_extends_1.deepExtends.apply(this, objects)];
            }
        });
    });
}
exports.cobble = cobble;
