"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var cobble_1 = require("./cobble");
var fs = tslib_1.__importStar(require("fs-extra"));
describe('main', function () {
    it('works with two configs', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var fixedConnectionYaml, fileContents, resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    fixedConnectionYaml = 'test/configs/config-fixed-connection.yaml';
                    fileContents = 'fixedConnections.0.name: override';
                    return [4, fs.writeFile(fixedConnectionYaml, fileContents)];
                case 1:
                    _a.sent();
                    return [4, cobble_1.cobble({
                            inputs: [
                                'test/configs/config-simple.yaml',
                                'test/configs/config-fixed-connection.yaml'
                            ]
                        })];
                case 2:
                    resp = _a.sent();
                    expect(resp.fixedConnections[0].name).toEqual('override');
                    return [4, fs.remove(fixedConnectionYaml)];
                case 3:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('works with inline vars', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, cobble_1.cobble({
                        inputs: [
                            { raw: "{'userNameLabel': 'welcome to %{subdivision}%'}" }
                        ],
                        varsObj: { subdivision: 'pots and pans' }
                    })];
                case 1:
                    resp = _a.sent();
                    expect(resp.userNameLabel).toEqual('welcome to pots and pans');
                    return [2];
            }
        });
    }); });
    it('works with ignoreMissingVariables', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, cobble_1.cobble({
                        inputs: [
                            { raw: "{'userNameLabel': 'welcome to %{subdivision}%', 'sometimesDefined': '%{SOMETIMES_DEFINED}%' }" }
                        ],
                        varsObj: { subdivision: 'pots and pans' },
                        ignoreMissingVariables: true,
                    })];
                case 1:
                    resp = _a.sent();
                    expect(resp).toEqual({
                        "userNameLabel": "welcome to pots and pans"
                    });
                    return [2];
            }
        });
    }); });
    it('throws with missing variables without ignoreMissingVariables', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            expect(cobble_1.cobble({
                inputs: [
                    { raw: "{'userNameLabel': 'welcome to %{subdivision}%', 'sometimesDefined': '%{SOMETIMES_DEFINED}%' }" }
                ],
                varsObj: { subdivision: 'pots and pans' }
            })).rejects.toEqual(new Error("could not find variable '%{SOMETIMES_DEFINED}%'"));
            return [2];
        });
    }); });
    it('works with dot properties', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var dotProperties, fileContents, resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    dotProperties = 'test/configs/config.properties';
                    fileContents = 'userNameLabel=myDotPropertiesLabel';
                    return [4, fs.writeFile(dotProperties, fileContents)];
                case 1:
                    _a.sent();
                    return [4, cobble_1.cobble({
                            inputs: [
                                'test/configs/config-simple.yaml',
                                'test/configs/config.properties'
                            ]
                        })];
                case 2:
                    resp = _a.sent();
                    expect(resp.userNameLabel).toEqual('myDotPropertiesLabel');
                    return [4, fs.remove(dotProperties)];
                case 3:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('works with json overrides', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, cobble_1.cobble({
                        inputs: [
                            'test/configs/config-simple.yaml',
                            { raw: "{'userMode': 'special-user'}" }
                        ]
                    })];
                case 1:
                    resp = _a.sent();
                    expect(resp.userMode).toEqual('special-user');
                    return [2];
            }
        });
    }); });
    it('works with yaml documents', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var dotProperties, dotPropertiesContents, tracksYaml, tracksYamlContents, documentsYaml, documentsYamlContents, footnoteYaml, footnoteContents, footnoteJSON, footnoteJSONContents, footnoteText, footnoteTextContents, mixedFile, mixedContent, resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    dotProperties = 'test/configs/config.properties';
                    dotPropertiesContents = 'nest.userNameLabel=myDotPropertiesLabel';
                    return [4, fs.writeFile(dotProperties, dotPropertiesContents)];
                case 1:
                    _a.sent();
                    tracksYaml = 'test/configs/tracks.yaml';
                    tracksYamlContents = "\n    - title: Respond/react\n      length: '5:07'\n    - title: Section\n      length: '4:08'\n    - title: '%{TRACK_TITLE}%'\n      length: '1:24'\n    - title: It just don't stop\n      length: '4:33'\n    - title: '%{TRACK_TITLE_TWO || unknown}%'\n      length: '5:16'\n";
                    return [4, fs.writeFile(tracksYaml, tracksYamlContents)];
                case 2:
                    _a.sent();
                    documentsYaml = 'test/configs/config-documents.yaml';
                    documentsYamlContents = "\n---\n# Some songs\ntracks: $read_yaml(tracks.yaml)\ntracksAgain: $read_yaml(tracks.yaml)\n...\n---\ntracks.2.title: Panic!!!(edited)\n...\n    ";
                    return [4, fs.writeFile(documentsYaml, documentsYamlContents)];
                case 3:
                    _a.sent();
                    footnoteYaml = 'test/configs/footnote.yaml';
                    footnoteContents = "|\n  -----BEGIN FOOTNOTE-----\n  Charted only on the Bubbling Under Hot 100 Singles or \n  Bubbling Under R&B/Hip-Hop Singles charts, 25-song extensions to the \n  Billboard Hot 100 and Hot R&B/Hip-Hop Songs charts respectively.\n  -----END FOOTNOTE-----\n";
                    return [4, fs.writeFile(footnoteYaml, footnoteContents)];
                case 4:
                    _a.sent();
                    footnoteJSON = 'test/configs/footnote.json';
                    footnoteJSONContents = {
                        "elements": [
                            {
                                "distance": {
                                    "text": "94.6 mi",
                                    "value": 152193
                                },
                                "duration": {
                                    "text": "1 hour 44 mins",
                                    "value": 6227
                                },
                                "status": "OK"
                            }
                        ]
                    };
                    return [4, fs.writeJSON(footnoteJSON, footnoteJSONContents)];
                case 5:
                    _a.sent();
                    footnoteText = 'test/configs/footnote.txt';
                    footnoteTextContents = "\n<!DOCTYPE html>\n<html>\n<body>\n\n<h1 style=\"color:blue;\">This is a heading</h1>\n<p style=\"color:red;\">This is a paragraph.</p>\n\n</body>\n</html>\n    ";
                    return [4, fs.writeFile(footnoteText, footnoteTextContents)];
                case 6:
                    _a.sent();
                    mixedFile = 'test/configs/config-mixed.yaml';
                    mixedContent = "\n---\naddendum:\n    - title: Outro\n      details: |\n        '1996'\n        A major record deal \n        and some international notoriety\nfootnote: $read_yaml(footnote.yaml)\nfootnote2: $read_json(footnote.json)\nfootnote3: \n  - name: ey \n    value: $read_text(footnote.txt)\n...\n---\n! some last minute edits\ntracks.1.title = Section(edited)\nblue = note will\n...\n\n";
                    return [4, fs.writeFile(mixedFile, mixedContent)];
                case 7:
                    _a.sent();
                    return [4, cobble_1.cobble({
                            inputs: [
                                documentsYaml,
                                dotProperties,
                                mixedFile
                            ],
                            debug: console.log,
                            varsObj: {
                                'TRACK_TITLE': 'Panic!!!!!'
                            }
                        })];
                case 8:
                    resp = _a.sent();
                    expect(resp).toEqual({
                        "addendum": [
                            {
                                "details": "'1996'\nA major record deal \nand some international notoriety\n",
                                "title": "Outro"
                            }
                        ],
                        "blue": "note will",
                        "footnote": "-----BEGIN FOOTNOTE-----\nCharted only on the Bubbling Under Hot 100 Singles or \nBubbling Under R&B/Hip-Hop Singles charts, 25-song extensions to the \nBillboard Hot 100 and Hot R&B/Hip-Hop Songs charts respectively.\n-----END FOOTNOTE-----\n",
                        "footnote2": footnoteJSONContents,
                        "footnote3": [
                            {
                                "name": "ey",
                                "value": "\n<!DOCTYPE html>\n<html>\n<body>\n\n<h1 style=\"color:blue;\">This is a heading</h1>\n<p style=\"color:red;\">This is a paragraph.</p>\n\n</body>\n</html>\n    "
                            }
                        ],
                        "nest": {
                            "userNameLabel": "myDotPropertiesLabel"
                        },
                        "tracks": [
                            {
                                "length": "5:07",
                                "title": "Respond/react"
                            },
                            {
                                "length": "4:08",
                                "title": "Section(edited)"
                            },
                            {
                                "length": "1:24",
                                "title": "Panic!!!(edited)"
                            },
                            {
                                "length": "4:33",
                                "title": "It just don't stop"
                            },
                            {
                                "length": "5:16",
                                "title": "unknown"
                            }
                        ],
                        "tracksAgain": [
                            {
                                "length": "5:07",
                                "title": "Respond/react"
                            },
                            {
                                "length": "4:08",
                                "title": "Section"
                            },
                            {
                                "length": "1:24",
                                "title": "Panic!!!!!"
                            },
                            {
                                "length": "4:33",
                                "title": "It just don't stop"
                            },
                            {
                                "length": "5:16",
                                "title": "unknown"
                            }
                        ]
                    });
                    return [4, fs.remove(dotProperties)];
                case 9:
                    _a.sent();
                    return [4, fs.remove(documentsYaml)];
                case 10:
                    _a.sent();
                    return [4, fs.remove(mixedFile)];
                case 11:
                    _a.sent();
                    return [4, fs.remove(tracksYaml)];
                case 12:
                    _a.sent();
                    return [4, fs.remove(footnoteYaml)];
                case 13:
                    _a.sent();
                    return [4, fs.remove(footnoteJSON)];
                case 14:
                    _a.sent();
                    return [4, fs.remove(footnoteText)];
                case 15:
                    _a.sent();
                    return [2];
            }
        });
    }); });
});
