"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var object_utils_1 = require("../object-utils/object-utils");
function deepCloneArray(arr) {
    var clonedArr = [];
    arr.forEach(function (item, i) {
        if (typeof item === 'object' && item != null) {
            if (Array.isArray(item)) {
                clonedArr[i] = deepCloneArray(item);
            }
            else {
                clonedArr[i] = deepExtends({}, item);
            }
        }
        else {
            clonedArr[i] = item;
        }
    });
    return clonedArr;
}
function resolveNewValue(oldVal, newVal) {
    if (typeof newVal !== 'object' || newVal === null)
        return newVal;
    if (Array.isArray(newVal))
        return deepCloneArray(newVal);
    if (typeof oldVal !== 'object' || oldVal === null || Array.isArray(oldVal))
        return deepExtends({}, newVal);
    return deepExtends(oldVal, newVal);
}
function deepExtends(target) {
    var sources = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        sources[_i - 1] = arguments[_i];
    }
    var args = Array.prototype.slice.call(arguments);
    if (args.length < 1 || typeof args[0] !== 'object') {
        throw new Error("Invalid arguments: [" + args.toString() + "] must provide a list of json values.");
    }
    if (args.length === 1)
        return target;
    var newVal;
    var previousValue;
    args.forEach(function (obj) {
        if (typeof obj !== 'object' || obj === null || Array.isArray(obj)) {
            return;
        }
        Object.keys(obj).forEach(function (key) {
            previousValue = target[key];
            newVal = obj[key];
            if (newVal === target) {
                return;
            }
            target = object_utils_1.deepSet(target, key, resolveNewValue(previousValue, newVal));
        });
    });
    return target;
}
exports.deepExtends = deepExtends;
