"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var parsing_1 = require("../parsing/parsing");
var deep_extends_1 = require("../deep-extends/deep-extends");
var fs = require("fs-extra");
var getPathAndFormat = function (input) {
    if (typeof input === 'string') {
        return { path: input };
    }
    else if (!input.raw) {
        return { path: input.path, format: input.format };
    }
    else {
        return { path: null, format: null };
    }
};
var getFileData = function (input, path) {
    if (path) {
        try {
            return fs.readFile(path, 'utf-8');
        }
        catch (e) {
            console.log("error in read: for " + path + ": " + e.message);
            return null;
        }
    }
    if (input.raw) {
        return input.raw;
    }
    return null;
};
function main(params) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var inputs, debug, objects;
        var _this = this;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    inputs = params.inputs;
                    debug = params.debug || (function (v) { });
                    if (!Array.isArray(inputs)) {
                        throw new Error("Please provide a list of inputs either as strings or { path: string, format: 'json' | 'yaml' | 'properties' } objects");
                    }
                    objects = [];
                    return [4, Promise.all(inputs.map(function (input) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                            var _a, path, format, fileData, parsed, e_1;
                            return tslib_1.__generator(this, function (_b) {
                                switch (_b.label) {
                                    case 0:
                                        _a = getPathAndFormat(input), path = _a.path, format = _a.format;
                                        return [4, getFileData(input, path)];
                                    case 1:
                                        fileData = _b.sent();
                                        if (!fileData) return [3, 5];
                                        _b.label = 2;
                                    case 2:
                                        _b.trys.push([2, 4, , 5]);
                                        return [4, parsing_1.tryParse(fileData, format)];
                                    case 3:
                                        parsed = _b.sent();
                                        objects = objects.concat(parsed);
                                        debug("parsed: " + JSON.stringify(parsed));
                                        return [3, 5];
                                    case 4:
                                        e_1 = _b.sent();
                                        debug("Could not parse: " + fileData + ": " + e_1.message + ", continuing");
                                        return [3, 5];
                                    case 5: return [2];
                                }
                            });
                        }); }))];
                case 1:
                    _a.sent();
                    if (!objects.length) {
                        throw new Error('No objects to work with');
                    }
                    objects = objects.filter(Boolean);
                    if (params.varsObj) {
                        objects = objects.map(function (object) { return parsing_1.inlineVars(object, params.varsObj); });
                    }
                    return [2, deep_extends_1.deepExtends.apply(this, objects)];
            }
        });
    });
}
exports.main = main;
