"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var main_1 = require("./main");
var fs = require("fs-extra");
describe('main', function () {
    it('works with two configs', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var fixedConnectionYaml, fileContents, resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    fixedConnectionYaml = 'test/configs/config-fixed-connection.yaml';
                    fileContents = 'fixedConnections.0.name: override';
                    return [4, fs.writeFile(fixedConnectionYaml, fileContents)];
                case 1:
                    _a.sent();
                    return [4, main_1.main({
                            inputs: [
                                'test/configs/config-simple.yaml',
                                'test/configs/config-fixed-connection.yaml'
                            ]
                        })];
                case 2:
                    resp = _a.sent();
                    expect(resp.fixedConnections[0].name).toEqual('override');
                    return [4, fs.remove(fixedConnectionYaml)];
                case 3:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('works with inline vars', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4, main_1.main({
                        inputs: [
                            { raw: "{'userNameLabel': 'welcome to %{subdivision}%'}" }
                        ],
                        varsObj: { subdivision: 'pots and pans' }
                    })];
                case 1:
                    resp = _a.sent();
                    expect(resp.userNameLabel).toEqual('welcome to pots and pans');
                    return [2];
            }
        });
    }); });
    it('works with dot properties', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var dotProperties, fileContents, resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    dotProperties = 'test/configs/config.properties';
                    fileContents = 'userNameLabel=myDotPropertiesLabel';
                    return [4, fs.writeFile(dotProperties, fileContents)];
                case 1:
                    _a.sent();
                    return [4, main_1.main({
                            inputs: [
                                'test/configs/config-simple.yaml',
                                'test/configs/config.properties'
                            ]
                        })];
                case 2:
                    resp = _a.sent();
                    expect(resp.userNameLabel).toEqual('myDotPropertiesLabel');
                    return [4, fs.remove(dotProperties)];
                case 3:
                    _a.sent();
                    return [2];
            }
        });
    }); });
    it('works with yaml documents', function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var dotProperties, fileContentsProperties, documentsYaml, fileContents, resp;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    dotProperties = 'test/configs/config.properties';
                    fileContentsProperties = 'userNameLabel=myDotPropertiesLabel';
                    return [4, fs.writeFile(dotProperties, fileContentsProperties)];
                case 1:
                    _a.sent();
                    documentsYaml = 'test/configs/config-documents.yaml';
                    fileContents = "\n---\n# Some songs\ntracks:\n    - title: Respond/react\n      length: '5:07'\n    - title: Section\n      length: '4:08'\n    - title: Panic!!!!!\n      length: '1:24'\n    - title: It just don't stop\n      length: '4:33'\n...\n---\ntracks.2.title: Panic!!!(edited)\n...\n    ";
                    return [4, fs.writeFile(documentsYaml, fileContents)];
                case 2:
                    _a.sent();
                    return [4, main_1.main({
                            inputs: [
                                documentsYaml,
                                'test/configs/config.properties'
                            ]
                        })];
                case 3:
                    resp = _a.sent();
                    expect(resp).toEqual({
                        "tracks": [
                            {
                                "length": "5:07",
                                "title": "Respond/react"
                            },
                            {
                                "length": "4:08",
                                "title": "Section"
                            },
                            {
                                "length": "1:24",
                                "title": "Panic!!!(edited)"
                            },
                            {
                                "length": "4:33",
                                "title": "It just don't stop"
                            }
                        ],
                        "userNameLabel": "myDotPropertiesLabel"
                    });
                    return [4, fs.remove(dotProperties)];
                case 4:
                    _a.sent();
                    return [4, fs.remove(documentsYaml)];
                case 5:
                    _a.sent();
                    return [2];
            }
        });
    }); });
});
