"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function shallowCopy(v) {
    return Array.isArray(v) ? v.slice() : Object.assign({}, v);
}
exports.shallowCopy = shallowCopy;
function isEmpty(v) {
    return !(Array.isArray(v) ? v.length : Object.keys(v).length);
}
function parsePath(path) {
    var parts = [];
    var rest = path;
    while (rest) {
        var escapedMatch = rest.match(/^\{([^{}]*)\}(?:\.(.*))?$/);
        if (escapedMatch) {
            parts.push(escapedMatch[1]);
            rest = escapedMatch[2];
            continue;
        }
        var normalMatch = rest.match(/^([^.]*)(?:\.(.*))?$/);
        if (normalMatch) {
            parts.push(normalMatch[1]);
            rest = normalMatch[2];
            continue;
        }
        throw new Error("Could not parse path " + path);
    }
    return parts;
}
exports.parsePath = parsePath;
function makePath(parts) {
    return parts.map(function (p) { return p.includes('.') ? "{" + p + "}" : p; }).join('.');
}
exports.makePath = makePath;
function isAppend(key) {
    return key === '[append]' || key === '-1';
}
exports.isAppend = isAppend;
function mapRecord(record, fn) {
    var newRecord = {};
    var keys = Object.keys(record);
    for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
        var key = keys_1[_i];
        newRecord[key] = fn(record[key], key);
    }
    return newRecord;
}
exports.mapRecord = mapRecord;
function deepGet(value, path) {
    var parts = parsePath(path);
    for (var _i = 0, parts_1 = parts; _i < parts_1.length; _i++) {
        var part = parts_1[_i];
        value = (value || {})[part];
    }
    return value;
}
exports.deepGet = deepGet;
function deepSet(value, path, x) {
    var parts = parsePath(path);
    var myKey = parts.shift();
    var valueCopy = shallowCopy(value);
    if (Array.isArray(valueCopy) && isAppend(myKey))
        myKey = String(valueCopy.length);
    if (parts.length) {
        var nextKey = parts[0];
        var rest = makePath(parts);
        valueCopy[myKey] = deepSet(value[myKey] || (isAppend(nextKey) ? [] : {}), rest, x);
    }
    else {
        valueCopy[myKey] = x;
    }
    return valueCopy;
}
exports.deepSet = deepSet;
function deepDelete(value, path) {
    var valueCopy = shallowCopy(value);
    var parts = parsePath(path);
    var firstKey = parts.shift();
    if (parts.length) {
        var firstKeyValue = value[firstKey];
        if (firstKeyValue) {
            var restPath = makePath(parts);
            var prunedFirstKeyValue = deepDelete(value[firstKey], restPath);
            if (isEmpty(prunedFirstKeyValue)) {
                delete valueCopy[firstKey];
            }
            else {
                valueCopy[firstKey] = prunedFirstKeyValue;
            }
        }
        else {
            delete valueCopy[firstKey];
        }
    }
    else {
        if (Array.isArray(valueCopy) && !isNaN(Number(firstKey))) {
            valueCopy.splice(Number(firstKey), 1);
        }
        else {
            delete valueCopy[firstKey];
        }
    }
    return valueCopy;
}
exports.deepDelete = deepDelete;
function whitelistKeys(obj, whitelist) {
    var newObj = {};
    for (var _i = 0, whitelist_1 = whitelist; _i < whitelist_1.length; _i++) {
        var w = whitelist_1[_i];
        if (Object.prototype.hasOwnProperty.call(obj, w)) {
            newObj[w] = obj[w];
        }
    }
    return newObj;
}
exports.whitelistKeys = whitelistKeys;
function getAllKeys(obj, prefix) {
    if (prefix === void 0) { prefix = ''; }
    return Object.keys(obj).reduce(function (res, key) {
        if (obj[key] !== null && Object.prototype.toString.call(obj[key]) === '[object Object]') {
            return res.concat(getAllKeys(obj[key], prefix + key + '.'));
        }
        else {
            return res.concat([prefix + key]);
        }
    }, []);
}
exports.getAllKeys = getAllKeys;
