"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var object_utils_1 = require("./object-utils");
describe('object-change', function () {
    describe('parsePath', function () {
        it('works', function () {
            expect(object_utils_1.parsePath('hello.wow.0')).toEqual(['hello', 'wow', '0']);
            expect(object_utils_1.parsePath('hello.{wow.moon}.0')).toEqual(['hello', 'wow.moon', '0']);
            expect(object_utils_1.parsePath('hello.#.0.[append]')).toEqual(['hello', '#', '0', '[append]']);
        });
    });
    describe('makePath', function () {
        it('works', function () {
            expect(object_utils_1.makePath(['hello', 'wow', '0'])).toEqual('hello.wow.0');
            expect(object_utils_1.makePath(['hello', 'wow.moon', '0'])).toEqual('hello.{wow.moon}.0');
        });
    });
    describe('deepGet', function () {
        var thing = {
            hello: {
                'consumer.props': 'lol',
                wow: [
                    'a',
                    { test: 'moon' }
                ]
            },
            zetrix: null
        };
        it('works', function () {
            expect(object_utils_1.deepGet(thing, 'hello.wow.0')).toEqual('a');
            expect(object_utils_1.deepGet(thing, 'hello.wow.4')).toEqual(undefined);
            expect(object_utils_1.deepGet(thing, 'hello.{consumer.props}')).toEqual('lol');
        });
        it('works with arrays', function () {
            expect(object_utils_1.deepGet({ key: ['one'] }, 'key.0')).toEqual('one');
        });
    });
    describe('deepSet', function () {
        var thing = {
            hello: {
                wow: [
                    'a',
                    { test: 'moon' }
                ]
            },
            zetrix: null
        };
        it('works to set an existing thing', function () {
            expect(object_utils_1.deepSet(thing, 'hello.wow.0', 5)).toEqual({
                hello: {
                    wow: [
                        5,
                        {
                            test: 'moon'
                        }
                    ]
                },
                zetrix: null
            });
        });
        it('works to set a non-existing thing', function () {
            expect(object_utils_1.deepSet(thing, 'lets.do.this.now', 5)).toEqual({
                hello: {
                    wow: [
                        'a',
                        {
                            test: 'moon'
                        }
                    ]
                },
                lets: {
                    do: {
                        this: {
                            now: 5
                        }
                    }
                },
                zetrix: null
            });
        });
        it('works to set an existing array', function () {
            expect(object_utils_1.deepSet(thing, 'hello.wow.[append]', 5)).toEqual({
                hello: {
                    wow: [
                        'a',
                        {
                            test: 'moon'
                        },
                        5
                    ]
                },
                zetrix: null
            });
        });
    });
    describe('deepDelete', function () {
        var thing = {
            hello: {
                moon: 1,
                wow: [
                    'a',
                    { test: 'moon' }
                ]
            },
            zetrix: null
        };
        it('works to delete an existing thing', function () {
            expect(object_utils_1.deepDelete(thing, 'hello.wow')).toEqual({
                hello: { moon: 1 },
                zetrix: null
            });
        });
        it('works is harmless to delete a non-existing thing', function () {
            expect(object_utils_1.deepDelete(thing, 'hello.there.lol.why')).toEqual(thing);
        });
        it('removes things completely', function () {
            expect(object_utils_1.deepDelete(object_utils_1.deepDelete(thing, 'hello.wow'), 'hello.moon')).toEqual({
                zetrix: null
            });
        });
        it('works with arrays', function () {
            expect(JSON.parse(JSON.stringify(object_utils_1.deepDelete(thing, 'hello.wow.0')))).toEqual({
                hello: {
                    moon: 1,
                    wow: [
                        {
                            test: 'moon'
                        }
                    ]
                },
                zetrix: null
            });
        });
    });
    describe('getAllKeys', function () {
        it('works with nested', function () {
            expect(object_utils_1.getAllKeys({
                "key1": {
                    "subkey1": 2,
                    "subkey2": {
                        "three": 3
                    }
                },
                "key2": "things",
                "key3": null
            })).toEqual([
                "key1.subkey1",
                "key1.subkey2.three",
                "key2",
                "key3"
            ]);
        });
        it('works with nested array', function () {
            expect(object_utils_1.getAllKeys({
                "someProperties": {
                    "common": [
                        "a=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer\na=aer",
                        ""
                    ]
                }
            })).toEqual([
                'someProperties.common'
            ]);
        });
        it('works with not nested', function () {
            expect(object_utils_1.getAllKeys({
                "key1": "value1",
                "key2": "value2",
                "key3": null
            })).toEqual([
                "key1",
                "key2",
                "key3"
            ]);
        });
    });
});
