"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var properties = tslib_1.__importStar(require("properties"));
var yaml = tslib_1.__importStar(require("js-yaml"));
var path = tslib_1.__importStar(require("path"));
var fs = tslib_1.__importStar(require("fs-extra"));
var object_utils_1 = require("../object-utils/object-utils");
function splitYamlIntoDocs(fileData) {
    return fileData
        .split(/^(?:\s*\.\.\.\s*)?(?:---)?$(?:[^.])?/gm)
        .filter(function (doc) {
        return doc !== '' && doc != null;
    });
}
exports.splitYamlIntoDocs = splitYamlIntoDocs;
function resolveFiles(obj, currentDir) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var _a, _b, _i, key, value, fileName, format, args, fileData, e_1, _c, parsedYaml;
        return tslib_1.__generator(this, function (_d) {
            switch (_d.label) {
                case 0:
                    if (!(typeof obj === 'object')) return [3, 14];
                    _a = [];
                    for (_b in obj)
                        _a.push(_b);
                    _i = 0;
                    _d.label = 1;
                case 1:
                    if (!(_i < _a.length)) return [3, 14];
                    key = _a[_i];
                    if (!(Object.prototype.toString.call(obj[key]) === '[object Object]' || Array.isArray(obj[key]))) return [3, 3];
                    return [4, resolveFiles(obj[key], currentDir)];
                case 2:
                    _d.sent();
                    return [3, 13];
                case 3:
                    value = obj[key];
                    fileName = '';
                    format = '';
                    if (!value) return [3, 13];
                    args = String(value).match(/(?:\$read_(text|json|yaml))\((.*)\)/);
                    if (args && typeof args[1] === 'string' && typeof args[2] === 'string') {
                        format = args[1];
                        if (!args[2] || typeof args[2] !== 'string') {
                            throw new Error("invalid arguments");
                        }
                        fileName = path.resolve(currentDir, args[2]);
                    }
                    if (!fileName)
                        return [3, 13];
                    fileData = void 0;
                    _d.label = 4;
                case 4:
                    _d.trys.push([4, 6, , 7]);
                    return [4, fs.readFile(fileName, 'utf-8')];
                case 5:
                    fileData = (_d.sent());
                    return [3, 7];
                case 6:
                    e_1 = _d.sent();
                    throw new Error("Could not read file: " + fileName);
                case 7:
                    _c = format;
                    switch (_c) {
                        case 'text': return [3, 8];
                        case 'yaml': return [3, 9];
                        case 'json': return [3, 11];
                    }
                    return [3, 12];
                case 8:
                    obj[key] = fileData;
                    return [3, 13];
                case 9: return [4, yaml.safeLoad(String(key) + ": " + fileData)];
                case 10:
                    parsedYaml = _d.sent();
                    obj[key] = parsedYaml[key];
                    return [3, 13];
                case 11:
                    obj[key] = JSON.parse(fileData);
                    return [3, 13];
                case 12: throw new Error("Unsupported format: " + format);
                case 13:
                    _i++;
                    return [3, 1];
                case 14: return [2, obj];
            }
        });
    });
}
exports.resolveFiles = resolveFiles;
function replaceTokens(obj, vs, ignoreMissingVariables) {
    if (ignoreMissingVariables === void 0) { ignoreMissingVariables = false; }
    if (Object.prototype.toString.call(obj) === '[object Object]') {
        return object_utils_1.mapRecord(obj, function (v) { return replaceTokens(v, vs, ignoreMissingVariables); });
    }
    else if (Array.isArray(obj)) {
        return obj.map(function (element) { return replaceTokens(element, vs, ignoreMissingVariables); });
    }
    else if (typeof obj === 'string') {
        var matches = obj.match(/%{([\w-]+)(?:\s?\|\|\s?)?([\w-]+)?}%/g);
        if (!matches) {
            if (obj.match(/%{.*}%/)) {
                throw new Error("Tokens must only contain word characters and '-'");
            }
            return obj;
        }
        var token = matches[0];
        var unwrapped = token.substr(2, token.length - 4);
        var variables = unwrapped.split(/\s?\|\|\s?/);
        var variable = variables[0];
        if (!variable) {
            throw new Error("Unexpected variable: " + variable + " in token: " + token);
        }
        var v = vs[variable];
        if (v != undefined) {
            return obj.replace(token, v);
        }
        if (variables[1] != undefined) {
            var fallbackValue = variables[1];
            if (fallbackValue === 'null') {
                return null;
            }
            return fallbackValue;
        }
        if (ignoreMissingVariables) {
            return undefined;
        }
        throw new Error("could not find variable '" + token + "'");
    }
    return obj;
}
exports.replaceTokens = replaceTokens;
function tryParse(fileData, format) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var yamlResp;
        return tslib_1.__generator(this, function (_a) {
            if (!format || format === 'yaml') {
                try {
                    yamlResp = yaml.safeLoad(fileData);
                    if (typeof yamlResp === 'object')
                        return [2, yamlResp];
                }
                catch (e) {
                    if (format === 'yaml') {
                        throw new Error("Could not parse yaml: " + e.message);
                    }
                }
            }
            if (!format || format === 'properties') {
                try {
                    return [2, properties.parse(fileData)];
                }
                catch (e) {
                    if (format === 'properties') {
                        throw new Error("Could not parse properties: " + e.message);
                    }
                }
            }
            throw new Error("Could not parse: " + fileData);
        });
    });
}
exports.tryParse = tryParse;
