"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var parsing_1 = require("./parsing");
describe('parsing', function () {
    describe('replaceTokens', function () {
        it('works with basic', function () {
            expect(parsing_1.replaceTokens({ 'type': '%{type}%' }, { type: 'internal' })).toEqual({ "type": "internal" });
        });
        it('does not replace keys', function () {
            expect(parsing_1.replaceTokens({ '%type%': '%{type}%' }, { type: 'malice' })).toEqual({ "%type%": "malice" });
        });
        it('fails if it cannot find a variable if ignoreMissingVariables is not set', function () {
            expect(function () { return parsing_1.replaceTokens({ 'type': '%{type}%' }, {}); }).toThrow("could not find variable '%{type}%'");
        });
        it('throws a meaningful error if you probably meant to interpolate', function () {
            expect(function () { return parsing_1.replaceTokens({ 'type': '%{type || some illegal stuff}%' }, {}); }).toThrow("Tokens must only contain word characters and '-'");
        });
        it('does not match spaces that are not a part of || null', function () {
            expect(function () { return parsing_1.replaceTokens({ 'type': '%{lol moon}%' }, {}); }).toThrow("Tokens must only contain word characters and '-'");
        });
        it('does not fail if it cannot find a variable if ignoreMissingVariables is set', function () {
            expect(parsing_1.replaceTokens({ 'type': '%{type}%' }, {}, true)).toEqual({});
        });
        it('works with nested', function () {
            var obj = {
                "name": "Dealership1",
                "city": "Beijing",
                "fruitPatentRank": null,
                "patentedFruits": [null],
                "oranges": {
                    "orange1": "%{orange1}%",
                    "orange2": "blood",
                    "orange3": {
                        "type": "mandarin",
                        "brand": "%{brand3}%"
                    }
                },
                "appleNames": ['mcintosh', '%{INSERT_YOUR_FAVORITE_APPLE_HERE}%'],
                "appleRegistry": [
                    {
                        "owner": "Johnny",
                        "surname": "Appleseed",
                        "ownedApples": "mcintosh"
                    },
                    {
                        "owner": "%{INSERT_YOUR_NAME_HERE}%",
                        "surname": "%{INSERT_YOUR_LAST_NAME_HERE}%",
                        "ownedApples": "%{INSERT_YOUR_FAVORITE_APPLE_HERE}%"
                    }
                ],
                "deals": "%{DEALS || null}%"
            };
            expect(parsing_1.replaceTokens(obj, {
                'orange1': 'navel',
                'brand3': 'halo',
                'INSERT_YOUR_FAVORITE_APPLE_HERE': 'jazz',
                'INSERT_YOUR_NAME_HERE': 'Atalanta',
                'INSERT_YOUR_LAST_NAME_HERE': 'Melanion'
            }))
                .toEqual({
                "city": "Beijing",
                "name": "Dealership1",
                "oranges": {
                    "orange1": "navel",
                    "orange2": "blood",
                    "orange3": {
                        "brand": "halo",
                        "type": "mandarin"
                    }
                },
                "appleNames": ["mcintosh", "jazz"],
                "appleRegistry": [
                    {
                        "ownedApples": "mcintosh",
                        "owner": "Johnny",
                        "surname": "Appleseed"
                    },
                    {
                        "ownedApples": "jazz",
                        "owner": "Atalanta",
                        "surname": "Melanion"
                    }
                ],
                "fruitPatentRank": null,
                "patentedFruits": [null],
                "deals": null
            });
            expect(parsing_1.replaceTokens(obj, {
                'orange1': 'navel',
                'brand3': 'halo',
                'INSERT_YOUR_FAVORITE_APPLE_HERE': 'jazz',
                'INSERT_YOUR_NAME_HERE': 'Atalanta',
                'INSERT_YOUR_LAST_NAME_HERE': 'Melanion',
                'DEALS': 'apples'
            }).deals)
                .toEqual('apples');
        });
    });
    describe('splitYamlIntoDocs', function () {
        var yaml = "---\naddendum:\n    - title: Outro\n      details: |\n        '1996'\n        A major record deal \n        and some international notoriety\n...\n---\n! some last minute edits\ntracks.1.title = Section(edited)\nblue = note will\n...\n---\n! final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n...\n---\n! ---final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n...\n";
        expect(parsing_1.splitYamlIntoDocs(yaml)).toEqual([
            "addendum:\n    - title: Outro\n      details: |\n        '1996'\n        A major record deal \n        and some international notoriety\n",
            "! some last minute edits\ntracks.1.title = Section(edited)\nblue = note will\n",
            "! final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n",
            "! ---final commit edits...\ntracks.1.title = Section(edited FINAL)\nblues = note will\n"
        ]);
    });
});
